@@ -1,6 +1,6 @@
 package Astro::Coord::ECI::Meta;
 
-use 5.006002;
+use 5.006;
 
 use strict;
 use warnings;
@@ -17,12 +17,6 @@ sub new {
     return $self;
 }
 
-sub build_requires {
-    return +{
-	'Test::More'	=> 0.88,	# Because of done_testing().
-    };
-}
-
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
@@ -32,23 +26,14 @@ sub requires {
     my ( $self, @extra ) = @_;
 ##  if ( ! $self->distribution() ) {
 ##  }
-    return +{
-	'Carp'		=> 0,
-	'Data::Dumper'	=> 0,
-	'Exporter'	=> 5.64,
-	'IO::File'	=> 0,
-	'POSIX'		=> 0,
-	'Scalar::Util'	=> 0,
-	'Storable'	=> 0,
-	'constant'	=> 0,
-	'strict'	=> 0,
-	'warnings'	=> 0,
+    return {
+	'Params::Util'	=> 0.25,
 	@extra,
     };
 }
 
 sub requires_perl {
-    return 5.006002;
+    return 5.006;
 }
 
 
@@ -85,16 +70,6 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
-=head2 build_requires
-
- use YAML;
- print Dump( $meta->build_requires() );
-
-This method computes and returns a reference to a hash describing the
-modules required to build the C<Astro::Coord::ECI> package, suitable for
-use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
-C<< {META_MERGE}->{build_requires} >> key.
-
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -150,7 +125,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2015 by Thomas R. Wyant, III
+Copyright (C) 2010, Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
